@@ -268,78 +268,107 @@ def trash(f: Union[Path, str], detach=True) -> None:
         Path(f).unlink(missing_ok=True)
 
 
-def remove_whitespaace(string):
-    return " ".join(string.split())
+def repeat_until_same(fn):
+    def wrapper(*args, **kwargs):
+        p = args[0]
+        while True:
+            p1 = p
+            p = fn(p, *args[1:], **kwargs)
+            # print(fn.__name__, p)
+            if p1 == p:
+                break
+        return p
+
+    return wrapper
 
 
-def replace_consecutive(string, char=" "):
+def remove_consecutive_whitespace(string):
+    return " ".join(string.split())  # spaces, tabs, and newlines
+
+
+def remove_consecutive(string, char=" "):
     return re.sub("\\" + char + "+", char, string)
 
 
-def replace_consecutives(string, chars):
+@repeat_until_same
+def remove_consecutives(string, chars):
     for char in chars:
-        string = replace_consecutive(string, char)
-    for char in reversed(chars):
-        string = replace_consecutive(string, char)
+        string = remove_consecutive(string, char)
     return string
 
 
-def replace_basename_prefixes(string, prefixes):
+@repeat_until_same
+def remove_prefixes(string, prefixes):
     for prefix in prefixes:
-        string = string.replace("/" + prefix, "/").replace("\\" + prefix, "\\")
-    for prefix in reversed(prefixes):
-        string = string.replace("/" + prefix, "/").replace("\\" + prefix, "\\")
+        if string.startswith(prefix):
+            string = string.replace(prefix, "", 1)
     return string
 
 
-def replace_folder_ending(string, prefixes):
-    for prefix in prefixes:
-        string = string.replace(prefix + "/", "/").replace(prefix + "\\", "\\")
-    for prefix in reversed(prefixes):
-        string = string.replace(prefix + "/", "/").replace(prefix + "\\", "\\")
+@repeat_until_same
+def remove_suffixes(string, suffixes):
+    for suffix in suffixes:
+        if string.endswith(suffix):
+            string = string[: -len(suffix)]
     return string
 
 
-def clean_path(p):
+@repeat_until_same
+def clean_string(p):
+    p = (
+        p.replace("*", "")
+        .replace("&", "")
+        .replace("%", "")
+        .replace("$", "")
+        .replace("#", "")
+        .replace(" @", "")
+        .replace("?.", ".")
+        .replace("!.", ".")
+        .replace("^", "")
+        .replace("'", "")
+        .replace('"', "")
+        .replace(")", "")
+    )
+    p = remove_consecutives(p, chars=["."])
+    p = (
+        p.replace("(", " ")
+        .replace("-.", ".")
+        .replace(" :", ":")
+        .replace(" - ", " ")
+        .replace("- ", " ")
+        .replace(" -", " ")
+        .replace(" _ ", "_")
+        .replace(" _", "_")
+        .replace("_ ", "_")
+    )
+    p = remove_consecutive_whitespace(p)
+    return p
+
+
+def clean_path(b, dot_space=False):
+    p = b.decode("utf-8", "backslashreplace")
     p = ftfy.fix_text(p, explain=False)
     path = Path(p)
     ext = path.suffix
-    p = str(path.parent / path.stem)
 
-    while True:
-        p1 = p
-        p = (
-            p.replace("...", "…")
-            .replace("*", "")
-            .replace("&", "")
-            .replace("%", "")
-            .replace("$", "")
-            .replace("#", "")
-            .replace("@", "")
-            .replace("!", "")
-            .replace("^", "")
-            .replace("'", "")
-            .replace('"', "")
-            .replace(")", "")
-        )
-        p = replace_consecutives(p, chars=["-", "."])
-        p = (
-            p.replace("(", " ")
-            .replace("-.", ".")
-            .replace(" :", ":")
-            .replace(" - ", " ")
-            .replace("- ", " ")
-            .replace(" -", " ")
-            .replace(" _ ", "_")
-            .replace(" _", "_")
-            .replace("_ ", "_")
-        )
-        p = replace_folder_ending(p, [" ", "-", "_", "."])
-        p = replace_basename_prefixes(p, [" ", "-"])
-        p = remove_whitespaace(p)
-        p = re.sub(r"\.+$", "", p)
-        if p1 == p:
-            break
+    parent = [clean_string(part) for part in path.parent.parts]
+    stem = clean_string(path.stem)
+    # print('cleaned',parent, stem)
+
+    parent = [remove_prefixes(part, [" ", "-"]) for part in parent]
+    # print('parent_prefixes', parent, stem)
+    parent = [remove_suffixes(part, [" ", "-", "_", "."]) for part in parent]
+    # print('parent_suffixes', parent, stem)
+
+    stem = remove_prefixes(stem, [" ", "-"])
+    stem = remove_suffixes(stem, [" ", "-", "."])
+    # print('stem', parent, stem)
+
+    parent = ["_" if part == "" else part for part in parent]
+    p = str(Path(*parent) / stem[:1024])
+
+    if dot_space:
+        p = p.replace(" ", ".")
 
     return p + ext
 
@@ -459,6 +488,9 @@ def mpv_enrich2(args, media) -> List[dict]:
 
 
 def dict_filter_bool(kwargs, keep_0=True) -> Optional[dict]:
+    if kwargs is None:
+        return None
+
     if keep_0:
         filtered_dict = {k: v for k, v in kwargs.items() if v is not None and v != "" and v is not False}
     else:
